
@echo off

setlocal EnableDelayedExpansion

cls

set scriptName=%~n0
set minWindowsVersion=Windows Vista
set minWindowsVersionNumber=06000
set features=mit 1 GB RAM
set skilliesConfigNameDefault="Skillies-Konfiguration %features%"
set timeout=10

::Identify OS
for /F "delims=" %%a in ('ver') do set ver=%%a
set windowsVersion=Unknown
set windowsVersionMajor=0
set windowsVersionMinor=0
for %%a in (10.0=10 6.3.=08.1 6.2.=8 6.1.=7 6.0.=Vista 5.2.=2003 5.1.=XP 2000=2000 ME=ME NT=NT 98=98 95=95) do (
	if "!windowsVersion!" EQU "this" (
		set windowsVersion=Windows %%a
		goto WindowsVersionFound
	) else if "!ver: %%a=!" NEQ "%ver%" (
		set windowsVersion=this
		for /f "tokens=1 delims=. " %%b in ('echo %%a') do set windowsVersionMajor=%%b
		for /f "tokens=2 delims=. " %%b in ('echo %%a') do set windowsVersionMinor=%%b
	)
)
:NoWindowsVersionFound
echo.
echo Ihr Betriebssystem konnte nicht ermittelt werden.
echo Bitte wenden Sie sich an unseren Support.
echo.
goto End

:WindowsVersionFound
rem set version number as integer with five places for comparisons
set windowsVersionMajor=0%windowsVersionMajor%
set windowsVersionMajor=%windowsVersionMajor:~-2%
set windowsVersionNumber=%windowsVersionMajor%%windowsVersionMinor%00000
set windowsVersionNumber=%windowsVersionNumber:~0,5%

set windowsVersionSwitch=NotOk
if %windowsVersionNumber% GEQ %minWindowsVersionNumber% set windowsVersionSwitch=Ok
goto WindowsVersion%windowsVersionSwitch%

:WindowsVersionNotOk
echo.
echo Auf diesem Computer wurde das Betriebssystem %windowsVersion% gefunden.
echo Dieses Skript kann jedoch erst ab %minWindowsVersion% verwendet werden.
echo.
echo Bitte lesen Sie die Beschreibung zum Erstellen einer alternativen
echo Bootkonfiguration fr die Skillies in den FAQ auf unserer Website
echo www.skilles.de im Punkt "Wie kann ich auch mit mehr als 1 GB RAM
echo mit den Skillies arbeiten?". Dort finden Sie auch die Beschreibung
echo fr Ihre Windowsversion.
echo.
goto End

:WindowsVersionOk

echo.
if "%1" == "-h" (
    goto Usage
)
if "%1" == "--help" (
    goto Usage
)
if "%1" == "/?" (
    goto Usage
)
if "%1" == "-?" (
    goto Usage
)
if "%1" == "?" (
    goto Usage
)
set SkilliesConfigName=%skilliesConfigNameDefault%
if not {%1} == {} (
    set SkilliesConfigName=%1
)

echo.
echo Dieses Skript erstellt eine alternative Bootkonfiguration
echo fr die Skillies %features% mit dem Namen
echo %SkilliesConfigName%.
echo.
echo Dadurch knnen Sie knftig beim Start Ihres Computers zwischen
echo Ihrer bisherigen Konfiguration und dieser fr die Skillies
echo optimierten Konfiguration auswhlen.
echo.
echo Als Standard bleibt Ihre bisherige Konfiguration bestehen
echo und wird, wenn Sie keine Auswahl treffen, nach %timeout% Sekunden
echo automatisch gestartet.
echo.
echo Bitte beachten Sie, dass Windows mit der eingeschrnkten
echo Systemkonfiguration %features% sehr wahrscheinlich
echo langsamer luft und auch andere Programme eventuell schlechter
echo funktionieren.
echo Verwenden Sie daher die Bootkonfiguration fr die Skillies nur
echo fr die Arbeit mit dem Programm "Skillies" und starten Sie
echo anschlieend den Computer neu mit der Standardbootkonfiguration.
echo.
echo Hinweis: Dieses Skript wurde sorgfltig erstellt und getestet,
echo jedoch erfolgt die Ausfhrung auf eigene Gefahr.

:ConfirmCreateBootConfig
set createBootConfig=
echo.
echo Soll nun die alternative Bootkonfiguration fr die Skillies
set /p createBootConfig="erstellt werden? [J/N] "
if not defined createBootConfig (
	echo.
	echo Bitte geben Sie J oder N ein!
	goto ConfirmCreateBootConfig
)
if /i "%createBootConfig:"=%"=="J" goto CreateBootConfigConfirmed
if /i "%createBootConfig:"=%"=="N" goto CreateBootConfigCancelled
goto ConfirmCreateBootConfig

:CreateBootConfigCancelled
echo.
echo Das Skript wird abgebrochen.
echo Es wurden keine nderungen an Ihrem System vorgenommen.
goto End

:CreateBootConfigConfirmed
call :IsAdmin
if not %errorlevel% == 0 (
	:: Set red background and beep
	color CF
	@echo 
	echo Fehler:    Zugriff verweigert.
	echo.
	goto Usage
)

rem Use creation date and time as postfix for name of boot menu backup
set backup_date=%date:~6,4%%date:~3,2%%date:~0,2%
set backup_time=%time: =0%
set backup_time=%backup_time::=%
set backup_time=%backup_time:.=%
set backup_time=%backup_time:,=%
set backup_time=%backup_time:~0,6%
set bootMenuBackupDir=%~dp0
set bootMenuBackupName=BootmenuBackup_%backup_date%_%backup_time%.bin
set bootMenuBackupFile=%bootMenuBackupDir%\BootmenuBackup_%backup_date%_%backup_time%.bin
set bootMenuBackupFile=%bootMenuBackupFile:\\=\%

echo.
echo Backup der Bootkonfigurationen wird erstellt ...
echo %bootMenuBackupFile%
bcdedit /export "%bootMenuBackupFile%"
if errorlevel 1 (
    echo Fehler: Backup der Bootkonfiguration konnte nicht erstellt werden.
    goto ErrorExit
)

echo.
echo Bootkonfiguration %SkilliesConfigName% wird erstellt ...
rem Need to store the output of the copy (the GUID of the copy).
rem Need to have write permissions in the %temp% folder (assumed)
cmd /c "bcdedit /copy {current} /d %SkilliesConfigName%" > %temp%\tmpSkilliesConfGUID.txt

rem Find the GUID in the output of the BCDEdit   
for /f "tokens=2 delims={}" %%A in (%temp%\tmpSkilliesConfGUID.txt) DO set GUID=%%A

rem cleanup temp GUID file
del %temp%\tmpSkilliesConfGUID.txt > nul 2>&1

if "%GUID%" == "" (
    echo Fehler: GUID der Skillies-Bootkonfiguration konnte nicht erkannt werden.
    goto ErrorExit
)
set GUID={%GUID%}

echo GUID der Skillies-Bootkonfiguration = %GUID%
echo.

echo Skillies-Bootkonfiguration wird konfiguriert...

echo... Maximaler Speicher wird auf 1 GB gesetzt
bcdedit /set %GUID% TRUNCATEMEMORY 1073741824
if errorlevel 1 (
    echo Fehler: Skillies-Bootkonfiguration konnte nicht konfiguriert werden.
    goto ErrorExit
)

echo... Zeitlimit fr die Anzeige des Bootmens wird auf %timeout% Sekunden gesetzt
bcdedit /timeout %timeout%
   
set setAsDefault=0
rem If BootOptionName was not passed the -d will be %1
if `%1` == `-d` (
 set setAsDefault=1
)
if `%2` == `-d` (
 set setAsDefault=1
)


if %setAsDefault% == 1 (
  echo... Skillies-Bootkonfiguration wird als Standardbootkonfiguration gesetzt
  bcdedit /default %GUID%
) 

echo.
echo Die Bootkonfiguration fr die Skillies wurde erstellt. 
echo Bitte starten Sie Ihren Computer neu, um diese neue
echo Bootkonfiguration auszuwhlen.
echo.
echo Starten Sie die Systemkonfiguration msconfig, um die neue
echo Bootkonfiguration anzuzeigen, zu ndern oder wieder aus dem
echo Bootmen zu lschen.
goto Exit

:ErrorExit
echo.
echo Die Bootkonfiguration fr die Skillies konnte nicht erfolgreich
echo erstellt werden.
echo.
echo Bitte kopieren Sie den Text aus diesem Fenster oder erstellen Sie
echo einen Screenshot. Wenden Sie sich damit bitte an den Computer-
echo Administrator oder erneut an den Skillies-Support!
goto Exit

:Exit
echo.
set reset=
rem Kommentar bei der folgenden Zeile wieder entfernen, um die Debugoptionen wieder einzuschalten
rem set /p reset=Bootkonfiguration wieder entfernen? [j/n]
if "%reset%"=="j" goto Reset
if "%reset%"=="J" goto Reset
goto End

:Reset
echo.
bcdedit 
pause
bcdedit /delete %GUID%
goto End

:Usage
echo.
echo Hinweis:   Dieses Skript muss mit Administratorrechten ausgefhrt
echo            werden.
echo.
echo            ffnen Sie dazu eine Eingabeaufforderung mit Administrator-
echo            rechten, ziehen dann dieses Skript mit der Maus hinein und
echo            besttigen Sie mit der Enter-Taste.

if "%windowsVersion%" EQU "Windows Vista" (
	echo.
	echo            Unter Windows Vista funktioniert das Ziehen mit der Maus
	echo            leider nicht, hier mssen Sie den gesamten Pfad zum Skript
	echo            eingeben.
)
echo.
echo            Wahlweise knnen Sie das Skript auch im Windows Explorer mit
echo            der rechten Maustaste anklicken und aus dem Kontextmen den
echo            Eintrag "Als Administrator ausfhren" auswhlen.
echo.
echo.
echo Syntax:    %scriptName% [BootOptionName] [-d] [-h]
echo.
echo.           BootOptionName: der Name der Bootkonfiguration. Enthlt
echo            der Name Leerzeichen, muss er in Anfhrungszeichen ein-
echo            geschlossen werden. Diese Angabe ist optional. Ohne Angabe
echo            wird die Bootkonfiguration mit der Standardbezeichnung
echo            %skilliesConfigNameDefault% benannt.
echo.
echo            -d: gibt an, ob die Bootkonfiguration fr die Skillies
echo            die Standardbootkonfiguration werden soll. Ohne Angabe
echo            dieser Option wird die Standardbootkonfiguration nicht
echo            gendert.
echo.
echo            -h: zeigt diese Hinweise an.
echo.
echo Beispiele: %scriptName%
echo            %scriptName% "Konfiguration mit 1 GB RAM"
echo            %scriptName% -d
echo.
echo.
echo Hinweis:   Dieses Skript muss mit Administratorrechten ausgefhrt
echo            werden.
echo.
goto End

:End
echo.
for %%x in (%cmdcmdline%) do if /i "%%~x"=="/c" set DOUBLECLICKED=1
if defined DOUBLECLICKED pause
color
exit /b


:IsAdmin
fsutil dirty query %systemdrive% >nul
exit /b
